@@ -7,7 +7,17 @@ from .localization import Localization
 from .audiences import Audiences
 from .portfolios import Portfolios
 from .insights import Insights
+from . import sp as sponsored_products
+from . import sb as sponsored_brands
+from . import sd as sponsored_display
+
 __all__ = [
+    "sp",
+    "sb",
+    "sd",
+    "sponsored_products",
+    "sponsored_brands",
+    "sponsored_display",
     "Profiles",
     "Invoices",
     "Eligibility",
@@ -17,4 +27,4 @@ __all__ = [
     "Audiences",
     "Portfolios",
     "Insights"
-]
\ No newline at end of file
+]
